Tutorials — NeSy4PPM 0.1.0 documentation

# Tutorials

Here, you will find tutorials explaining how to utilize the different functionalities of NeSy4PPM. All tutorials can be downloaded and run from our Github. The tutorials use the Helpdesk log as a running example. List of available tutorials:

Tutorials

- NeSy4PPM: Suffix prediction Tutorial
- 1 Data preprocessing
  - 1.1 Data loading
  - 1.2 Prefixes extraction
  - 1.3 Prefixes encodings
  - End-to-end data preprocessing
- 2 Training
- 3 Prediction
  - 3.1 Set prediction parameters
  - 2.2 Load the Background Knowledge (BK)
  - 2.3 Perform Prediction
- 4 Evaluation